==> moodle-1.4.3-pgsql.tgz: moodle/lang/ko/exercise.php <==
<?PHP // $Id$ 
      // exercise.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['absent'] = 'Ἦ';
$string['accumulative'] = '';
$string['action'] = 'Ȱ';
$string['ago'] = '$a ';
$string['amend'] = 'ħ';
$string['amendassessmentelements'] = ' Ҹ ħ';
$string['amendtitle'] = ' ħ';
$string['assess'] = '';
$string['assessed'] = '򰡵';
$string['assessment'] = '';
$string['assessmentby'] = '$a  ';
$string['assessmentform'] = ' ';
$string['assessmentmadebythe'] = '$a   ';
$string['assessmentofthissubmission'] = ' ⹰ ';
$string['assessments'] = '';
$string['atthisstageyou'] = '̰  򰡿  κ ϼմϴ. 򰡿  е   ϱ⸦   ֽϴ.  ׷   򰡿  ͵ ؾ ϴ   ֽñ ٶϴ. е ؿ ־  (Re-assess) ũ Ŭ μ   ֽϴ. ';
$string['awaitingassessmentbythe'] = '$a  򰡸 ٸ';
$string['clearlateflag'] = ' ǥ ';
$string['comment'] = '';
$string['confirmdeletionofthisitem'] = '$a  ';
$string['correct'] = '';
$string['criterion'] = ' ';
$string['deadline'] = ' ';
$string['deadlineis'] = '  $a Դϴ.';
$string['delete'] = '';
$string['deleting'] = '';
$string['description'] = '';
$string['descriptionofexercise'] = '() Ȥ   Ÿ  ݵ MS   Ȥ HTML  Ǿ մϴ.    $a   ̸  Exercise ÷ մϴ. ÷  ٸ μ  մϴ. ̷   MS   HTML   Ǿ ϸ $a   ÷ մϴ. ';
$string['detailsofassessment'] = ' 󼼺';
$string['displayoffinalgrades'] = '  ';
$string['doubleupload'] = ' :  ⼭    Ǿϴ.   ż   2 ⼭ ȮϽñ ٶϴ.    2 ⼭ ϳ ñ ٶϴ.';
$string['duedate'] = '';
$string['edit'] = 'ġ';
$string['editingassessmentelements'] = ' Ҹ ġ';
$string['element'] = '';
$string['elementweight'] = ' ġ';
$string['entriessaved'] = '׸ ';
$string['errorbanded'] = ' ǥ';
$string['excellent'] = 'ſ ';
$string['exerciseassessments'] = 'Exercise ';
$string['exercisefeedback'] = ' ǵ';
$string['exercisesubmissions'] = ' ⹰';
$string['generalcomment'] = 'Ϲ ';
$string['good'] = '';
$string['gradeassessment'] = ' ';
$string['gradeforassessment'] = '򰡸  ';
$string['gradeforstudentsassessment'] = ' $a 򰡸  ';
$string['gradeforsubmission'] = '  ';
$string['gradetable'] = ' ǥ';
$string['gradingstrategy'] = ' ';
$string['handlingofmultiplesubmissions'] = ' ⹰ ó';
$string['hidenamesfromstudents'] = 'л ̸ ߱';
$string['incorrect'] = 'Ȯ';
$string['leaguetable'] = '   ǥ';
$string['mail1'] = '  \'$a\'    :';
$string['mail2'] = '    \'$a\'    ֽϴ.';
$string['mail3'] = '   ֽϴ.';
$string['mail6'] = '\'$a\' 򰡰 Ǿϴ.';
$string['mail7'] = '$a   ڸƮ Exercise Assignment( ) ϴ.';
$string['managingassignment'] = '  ';
$string['maximumsize'] = 'ִũ ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['movingtophase'] = '$a κ ̵';
$string['multiplesubmissions'] = 'ټ ⼭ ';
$string['noexercisedescriptionssubmitted'] = ' ü ʾ';
$string['nosubmissions'] = '⼭ ';
$string['notassessedyet'] = ' 򰡵 ';
$string['notavailable'] = '̿  ';
$string['noteonassessmentelements'] = '  򰡿ҡ зǾٴ  Ͻÿ.<br />
̰    ϰ ·  ݴϴ. <br /> ݵ ߰Ͽ մϴ.
() ϱ  ҵ л ̿  ֽϴ. ̰ <br />  ϴ.  ڽ ִ () Ŭϼ.   ҵ    ҵ ߰Ű  <br />  Դϴ.  ȭ顯<br /> ̿ν  ҵ ٲ  ֽϴ. ̷ ҵ ο:  ():ο뿡 Ǿ  ֽϴ. ';
$string['noteonstudentassessments'] = '{л   /   }';
$string['notgraded'] = 'ü  ʾ';
$string['notitlegiven'] = ' ־ ʾ';
$string['numberofassessmentelements'] = 'ڸƮ, 򰡿, ׷̵ , ǥ , ׸ з';
$string['numberofentries'] = '׸ ';
$string['numberofnegativeresponses'] = '  ';
$string['onesubmission'] = 'ϳ ⼭';
$string['optionaladjustment'] = '';
$string['overallgrade'] = '  ';
$string['phase'] = '';
$string['phase1'] = ' ¾';
$string['phase1short'] = '¾';
$string['phase2'] = '$a 򰡿 ⼭ ';
$string['phase2short'] = '';
$string['phase3'] = '   ϶ǥ ';
$string['phase3short'] = 'ǥ';
$string['pleasegradetheassessment'] = '$a  س 򰡼 üϿ ֽʽÿ.';
$string['pleasesubmityourwork'] = '  ̿Ͽ   Ͽ ֽʽÿ.';
$string['pleaseusethisform'] = 'ؿ ־  ġ    ϼֽʽÿ.';
$string['pleaseviewtheexercise'] = ' Ŭϸ ؿ ־ Ȱ ֽʽÿ. <br /> Ȱ ȿ ־   մϴ. ־   ġ ؿ ־ ڽ (Ȥ  ) Ŭ Ͻʽÿ. 򰡸 ϼϽø ׿   ־ϴ. ';
$string['reasonforadjustment'] = ' ';
$string['reassess'] = '';
$string['resubmissionfor'] = '$a ⼭';
$string['resubmitnote'] = '* $a ⼭    ִٴ  ǹմϴ. <br />  ÷״ <b> ִ <br /> Ŭϰų ν  ⼭ ־ϴ. $a </b> ν     ֽϴ. <br />л ÷װ ⼭        ֽϴ. ';
$string['rubric'] = '';
$string['savedok'] = ' Ȯ ';
$string['saveentries'] = ' ';
$string['savemyassessment'] = '  ';
$string['saveweights'] = 'Ʈ ';
$string['studentassessments'] = '$a ';
$string['studentnotallowed'] = '$a     ϴ.';
$string['studentsubmissions'] = '$a ⼭';
$string['studentsubmissionsforassessment'] = '$a 򰡸  л ⼭';
$string['submission'] = '⼭';
$string['submissions'] = '⼭()';
$string['submissionsnowclosed'] = '  ϴ-    ִ  ϴ. ';
$string['submitted'] = ' Ͽ.';
$string['submittedby'] = '  Ͽ.';
$string['teacherassessment'] = '$a ';
$string['teacherassessmenttable'] = '$a  ̺';
$string['teacherscomment'] = ' ڸƮ';
$string['thegradeis'] = ' $a';
$string['thereisfeedbackfromthe'] = '$a  ǵ .';
$string['thischarset'] = 'euc-kr';
$string['thislanguage'] = '&#54620;&#44397;&#50612;';
$string['title'] = '';
$string['view'] = '';
$string['weightforgradingofassessments'] = '   Ʈ';
$string['weightforteacherassessments'] = '$a 򰡿  Ʈ';
$string['weights'] = 'Ʈ';
$string['weightssaved'] = 'Ʈ ';
$string['weightsusedforoverallgrade'] = '   Ʈ';
$string['yourassessment'] = ' ';
$string['yourfeedbackgoeshere'] = ' ǵ ̰';
$string['yoursubmission'] = ' ⼭';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ko/exercise.php <==
<?PHP // $Id$



$string['absent'] = 'Ἦ';
$string['accumulative'] = '';
$string['action'] = 'Ȱ';
$string['ago'] = '$a ';
$string['amend'] = 'ħ';
$string['amendassessmentelements'] = ' Ҹ ħ';
$string['amendtitle'] = ' ħ';
$string['analysis'] = 'м';
$string['assess'] = '';
$string['assessed'] = '򰡵';
$string['assessment'] = '';
$string['assessmentby'] = '$a  ';
$string['assessmentform'] = ' ';
$string['assessmentmadebythe'] = '$a   ';
$string['assessmentofthissubmission'] = ' ⹰ ';
$string['assessments'] = '';
$string['atthisstageyou'] = '̰  򰡿  κ ϼմϴ. 򰡿  е   ϱ⸦   ֽϴ.  ׷   򰡿  ͵ ؾ ϴ   ֽñ ٶϴ. е ؿ ־  (Re-assess) ũ Ŭ μ   ֽϴ. ';
$string['awaitingassessmentbythe'] = '$a  򰡸 ٸ';
$string['clearlateflag'] = ' ǥ ';
$string['comment'] = '';
$string['comparisonofassessments'] = ' ';
$string['confirmdeletionofthisitem'] = '$a  ';
$string['correct'] = '';
$string['count'] = '';
$string['criterion'] = ' ';
$string['deadline'] = ' ';
$string['deadlineis'] = '  $a Դϴ.';
$string['delete'] = '';
$string['deletesubmissionwarning'] = ': $a 򰡰  Ȱ Բ յǾϴ.    ʵ ϰ ȵǾϴ.';
$string['deleting'] = '';
$string['description'] = '';
$string['descriptionofexercise'] = '() Ȥ   Ÿ  ݵ MS   Ȥ HTML  Ǿ մϴ.    $a   ̸  Exercise ÷ մϴ. ÷  ٸ μ  մϴ. ̷   MS   HTML   Ǿ ϸ $a   ÷ մϴ. ';
$string['detailsofassessment'] = ' 󼼺';
$string['displayoffinalgrades'] = '  ';
$string['doubleupload'] = ' :  ⼭    Ǿϴ.   ż   2 ⼭ ȮϽñ ٶϴ.    2 ⼭ ϳ ñ ٶϴ.';
$string['duedate'] = '';
$string['edit'] = 'ġ';
$string['editingassessmentelements'] = ' Ҹ ġ';
$string['element'] = '';
$string['elementweight'] = ' ġ';
$string['enterpassword'] = 'ȣ Է';
$string['entriessaved'] = '׸ ';
$string['errorbanded'] = ' ǥ';
$string['excellent'] = 'ſ ';
$string['exerciseassessments'] = 'Exercise ';
$string['exercisefeedback'] = ' ǵ';
$string['exercisesubmissions'] = ' ⹰';
$string['fair'] = '';
$string['generalcomment'] = 'Ϲ ';
$string['good'] = '';
$string['gradeassessment'] = ' ';
$string['gradeforassessment'] = '򰡸  ';
$string['gradeforstudentsassessment'] = ' $a 򰡸  ';
$string['gradeforsubmission'] = '  ';
$string['gradetable'] = ' ǥ';
$string['gradinggrade'] = ' ű';
$string['gradingstrategy'] = ' ';
$string['handlingofmultiplesubmissions'] = ' ⹰ ó';
$string['hidenamesfromstudents'] = 'л ̸ ߱';
$string['incorrect'] = 'Ȯ';
$string['late'] = 'ֱ';
$string['lax'] = '';
$string['leaguetable'] = '   ǥ';
$string['mail1'] = '  \'$a\'    :';
$string['mail2'] = '    \'$a\'    ֽϴ.';
$string['mail3'] = '   ֽϴ.';
$string['mail6'] = '\'$a\' 򰡰 Ǿϴ.';
$string['mail7'] = '$a   ڸƮ Exercise Assignment( ) ϴ.';
$string['managingassignment'] = '  ';
$string['maximum'] = 'ִġ';
$string['maximumgradeforstudentassessments'] = 'лм  ְ : $a';
$string['maximumgradeforsubmissions'] = '  ְ : $a';
$string['maximumsize'] = 'ִũ ';
$string['mean'] = 'ǹ';
$string['minimum'] = 'ּġ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['movingtophase'] = '$a κ ̵';
$string['multiplesubmissions'] = 'ټ ⼭ ';
$string['noexercisedescriptionssubmitted'] = ' ü ʾ';
$string['nosubmissions'] = '⼭ ';
$string['notassessedyet'] = ' 򰡵 ';
$string['notavailable'] = '̿  ';
$string['noteonassessmentelements'] = '  򰡿ҡ зǾٴ  Ͻÿ.<br />
̰    ϰ ·  ݴϴ. <br /> ݵ ߰Ͽ մϴ.
() ϱ  ҵ л ̿  ֽϴ. ̰ <br />  ϴ.  ڽ ִ () Ŭϼ.   ҵ    ҵ ߰Ű  <br />  Դϴ.  ȭ顯<br /> ̿ν  ҵ ٲ  ֽϴ. ̷ ҵ ο:  ():ο뿡 Ǿ  ֽϴ. ';
$string['noteongradinggrade'] = '     $a    򰡿 Բ 󸶳  Ǿ° Դϴ.   ǿ  ϴ.';
$string['noteonstudentassessments'] = '{л   /   }';
$string['notgraded'] = 'ü  ʾ';
$string['notitlegiven'] = ' ־ ʾ';
$string['numberofassessmentelements'] = 'ڸƮ, 򰡿, ׷̵ , ǥ , ׸ з';
$string['numberofcriterionelements'] = 'ǥ   ϳ  ';
$string['numberofentries'] = '׸ ';
$string['numberofentriesinleaguetable'] = '  ϶ǥ  ';
$string['numberofnegativeresponses'] = '  ';
$string['onesubmission'] = 'ϳ ⼭';
$string['optionaladjustment'] = '';
$string['overallgrade'] = '  ';
$string['passwordprotectedexercise'] = 'ȣ Ʒ Ѿ ';
$string['phase'] = '';
$string['phase1'] = ' ¾';
$string['phase1short'] = '¾';
$string['phase2'] = '$a 򰡿 ⼭ ';
$string['phase2short'] = '';
$string['phase3'] = '   ϶ǥ ';
$string['phase3short'] = 'ǥ';
$string['pleasegradetheassessment'] = '$a  س 򰡼 üϿ ֽʽÿ.';
$string['pleasemakeyourownassessment'] = '$aκ    򰡸 ʽÿ.   ó л 򰡿 Բ ٰ ƮϽʽÿ.   ʿϴٰ ϴ κ ϰ  Ʒ ִ ư ϳ ŬϽʽÿ.';
$string['pleasesubmityourwork'] = '  ̿Ͽ   Ͽ ֽʽÿ.';
$string['pleaseusethisform'] = 'ؿ ־  ġ    ϼֽʽÿ.';
$string['pleaseviewtheexercise'] = ' Ŭϸ ؿ ־ Ȱ ֽʽÿ. <br /> Ȱ ȿ ־   մϴ. ־   ġ ؿ ־ ڽ (Ȥ  ) Ŭ Ͻʽÿ. 򰡸 ϼϽø ׿   ־ϴ. ';
$string['poor'] = '';
$string['present'] = '';
$string['reasonforadjustment'] = ' ';
$string['reassess'] = '';
$string['regradestudentassessments'] = 'л м ';
$string['resubmissionfor'] = '$a ⼭';
$string['resubmitnote'] = '* $a ⼭    ִٴ  ǹմϴ. <br />  ÷״ <b> ִ <br /> Ŭϰų ν  ⼭ ־ϴ. $a </b> ν     ֽϴ. <br />л ÷װ ⼭        ֽϴ. ';
$string['rubric'] = '';
$string['savedok'] = ' Ȯ ';
$string['saveentries'] = ' ';
$string['savemyassessment'] = '  ';
$string['saveweights'] = 'Ʈ ';
$string['scale10'] = '10 ̻ ';
$string['scale100'] = '100 ̻ ';
$string['scale20'] = '20 ̻ ';
$string['scalecorrect'] = '2 Ʈ Ȯ/Ȯ ';
$string['scaleexcellent4'] = '4 Ʈ ſ/ſ ';
$string['scaleexcellent5'] = '5 Ʈ ſ/ſ ';
$string['scaleexcellent7'] = '7 Ʈ ſ/ſ ';
$string['scalegood3'] = '3 Ʈ / ';
$string['scalepresent'] = '2 Ʈ ⼮/Ἦ ';
$string['scaleyes'] = '2 Ʈ /ƴϿ ';
$string['specimenassessmentform'] = 'ߺ  ';
$string['standarddeviation'] = 'ǥ Ż';
$string['strict'] = '';
$string['studentallowedtoresubmit'] = '$a   ';
$string['studentassessments'] = '$a ';
$string['studentnotallowed'] = '$a     ϴ.';
$string['studentsubmissions'] = '$a ⼭';
$string['studentsubmissionsforassessment'] = '$a 򰡸  л ⼭';
$string['submission'] = '⼭';
$string['submissions'] = '⼭()';
$string['submissionsnowclosed'] = '  ϴ-    ִ  ϴ. ';
$string['submitexercisedescription'] = '  Ͻÿ';
$string['submitted'] = ' Ͽ.';
$string['submittedby'] = '  Ͽ.';
$string['suggestedgrade'] = 'ȵ ';
$string['teacherassessment'] = '$a ';
$string['teacherassessmenttable'] = '$a  ̺';
$string['teacherscomment'] = ' ڸƮ';
$string['theexercise'] = '';
$string['theexerciseandthesubmissionby'] = ' $a  ';
$string['thegradeis'] = ' $a';
$string['thereisfeedbackfromthe'] = '$a  ǵ .';
$string['thisisaresubmission'] = '̰ $a    Ǿϴ. ׵    򰡴 ϴ. ο    ,  򰡸 ϰ  Ʒ ư ϳ Ŭֽʽÿ.';
$string['title'] = '';
$string['typeofscale'] = 'ũ ';
$string['unassessed'] = '$a 򰡵 ';
$string['ungradedstudentassessments'] = '$a ׷̵ л ';
$string['usemaximum'] = 'ִġ ̿';
$string['usemean'] = 'ǹ ̿';
$string['usepassword'] = 'ȣ ̿';
$string['verylax'] = 'ſ ָ';
$string['verypoor'] = 'ſ ';
$string['verystrict'] = 'ſ ';
$string['view'] = '';
$string['viewteacherassessment'] = '$a  ';
$string['warningonamendingelements'] = ': 򰡵 ȵǾ ϴ.  ,  ,  Ʈ ٲ ʽÿ.';
$string['weightederrorcount'] = '߸  Ʈ: $a';
$string['weightforgradingofassessments'] = '   Ʈ';
$string['weightforteacherassessments'] = '$a 򰡿  Ʈ';
$string['weights'] = 'Ʈ';
$string['weightssaved'] = 'Ʈ ';
$string['weightsusedforoverallgrade'] = '   Ʈ';
$string['wrongpassword'] = '  ߸ ȣ';
$string['yourassessment'] = ' ';
$string['yourfeedbackgoeshere'] = ' ǵ ̰';
$string['yoursubmission'] = ' ⼭';
?>
